summaryrefslogtreecommitdiff
path: root/recipes-images/images/files/apalis-tk1-mainline/tegra-uboot-flasher
diff options
context:
space:
mode:
Diffstat (limited to 'recipes-images/images/files/apalis-tk1-mainline/tegra-uboot-flasher')
-rwxr-xr-xrecipes-images/images/files/apalis-tk1-mainline/tegra-uboot-flasher/genext4fs.sh (renamed from recipes-images/images/files/apalis-tk1-mainline/tegra-uboot-flasher/genext3fs.sh)14
1 files changed, 7 insertions, 7 deletions
diff --git a/recipes-images/images/files/apalis-tk1-mainline/tegra-uboot-flasher/genext3fs.sh b/recipes-images/images/files/apalis-tk1-mainline/tegra-uboot-flasher/genext4fs.sh
index 93c2b60..56e79f5 100755
--- a/recipes-images/images/files/apalis-tk1-mainline/tegra-uboot-flasher/genext3fs.sh
+++ b/recipes-images/images/files/apalis-tk1-mainline/tegra-uboot-flasher/genext4fs.sh
@@ -1,5 +1,5 @@
#!/bin/sh
#creates a file containing a ext3 binary blob of the content of the ../rootfs folder
# sometimes we need the binary echo, not the shell builtin
ECHO=`which echo`
@@ -8,8 +8,8 @@ MOUNTPOINT="mnt/tdx-rootfs"
Usage()
{
- echo "creates a file containing a ext3 binary blob. Output file name taken from command line"
- echo "Usage: genext3fs.sh [OPTION]... dest_file_name"
+ echo "creates a file containing a ext4 binary blob. Output file name taken from command line"
+ echo "Usage: genext4fs.sh [OPTION]... dest_file_name"
echo "-h : Prints this message"
echo "-b : Sets the partition size in MBytes, default 256"
echo "-d : Selects the directory which contains the partition content, default ../rootfs"
@@ -37,10 +37,10 @@ done
#adjust the commandline arg for the now used options
shift $(($OPTIND - 1))
#create the file used for the loopbackdevice and format it for ext3
#answer y to "is not a block special device"
dd if=/dev/zero of=$@ bs=1024k count=$PARTITIONSIZE
-mkfs.ext3 -F -L rootfs $@
+mkfs.ext4 -F -L rootfs $@
#disable fsck checks based on mount count or time interval
tune2fs -c 0 -i 0 $@
@@ -49,12 +49,12 @@ sudo mkdir -p $MOUNTPOINT
sudo umount $MOUNTPOINT &> /dev/null
sudo rm -rf $MOUNTPOINT/*
#mount the file as a loopdevice
#there seems to be a race between mkfs.ext3 not yet finished and mount already trying to mount, so try until it works
MOUNTED=0
while [ "$MOUNTED" -eq "0" ] ; do
sync
sleep 1
- sudo mount $@ $MOUNTPOINT/ -o loop -t ext3
+ sudo mount $@ $MOUNTPOINT/ -o loop -t ext4
MOUNTED=`mount | grep -c "$MOUNTPOINT"`
done
#extract rootfs into the file
@@ -1,5 +1,5 @@
#!/bin/sh
-#creates a file containing a ext3 binary blob of the content of the ../rootfs folder
+#creates a file containing a ext4 binary blob of the content of the ../rootfs folder
# sometimes we need the binary echo, not the shell builtin
ECHO=`which echo`
@@ -37,10 +37,10 @@ done
#adjust the commandline arg for the now used options
shift $(($OPTIND - 1))
-#create the file used for the loopbackdevice and format it for ext3
+#create the file used for the loopbackdevice and format it for ext4
#answer y to "is not a block special device"
dd if=/dev/zero of=$@ bs=1024k count=$PARTITIONSIZE
@@ -49,12 +49,12 @@ sudo mkdir -p $MOUNTPOINT
sudo rm -rf $MOUNTPOINT/*
#mount the file as a loopdevice
-#there seems to be a race between mkfs.ext3 not yet finished and mount already trying to mount, so try until it works
+#there seems to be a race between mkfs.ext4 not yet finished and mount already trying to mount, so try until it works
MOUNTED=0
while [ "$MOUNTED" -eq "0" ] ; do